@@ -125,7 +125,7 @@ c             init for 1 event
        FirstInt.x = -100000
        FirstInt.y = -100000
        FirstInt.z = -100000
-       pathInB = 0.
+       pathInB=0.
        SumDe = 0.
        Move.Abort = 0     !  if this become non zero for an event, 
                      !  the particle is discarded or event is discarded
@@ -245,6 +245,7 @@ c              until current partile dies or all are put into stack.
 
       integer icon, info
 
+
       do while (.true.)
 c                current track is in  cTrack
 c          fix process and free path
@@ -387,6 +388,7 @@ c              local. coord..
 c     *************** see if Move.Track crosses the boundary ******
 c              set Cross=t/f, if t, adjust path and set Trunc=t
       call epifCross(icon)
+                                                                           
       if(icon .eq. 2) return  !  ptcl went void by delicate boundary.
       icon = 0
 cc      if(icon .eq. 0) then
@@ -394,6 +396,7 @@ c
 c     ************** energy loss consideration ******************
 c        if E becomes <= m,  adjust path and set Trunc=t,
 c        and reset Cross.
+
          if(cTrack.p.charge .ne. 0 .and. Move.dl .gt. 0.) then
             call epEloss
          else
@@ -506,7 +509,9 @@ c         update coord. to local one in new  comp.
          call epl2w(Cn, cTrack.pos, postemp)
          call epw2l(cnx, postemp,  cTrack.pos)
          call epl2wd(Cn, cTrack.w,  dirtemp)
-         call epw2ld(cnx, dirtemp, cTrack.w)
+ccc         call epw2ld(cnx, dirtemp, cTrack.w)
+         call epw2ldm(cnx, dirtemp, cTrack.w, cTrack.p)
+         
 c            update comp. info (Cn, MediaNo etc are updated)
          call epnewComp  
 #ifdef  SUBSTREC
@@ -1047,6 +1052,7 @@ c
 c         see if Move.Track is in Cn-th component.
 c          coord is local coord.
       call epbndry(Move.boundary, el, icon)
+                       
 c       icon =1 indicates something wrong. but 
 c       it should have been corrected safely so we don't
 c       care.
@@ -1250,7 +1256,15 @@ c
 c               stopped one. add decay time if possible
           call cgetctau(cTrack.p, ctau)
           if(ctau .eq. Infty) then
-             Move.Track.t= cTrack.t+1.e8
+c               If the particle is still to be treated
+c               even after it stops, the ptcl 
+c               should be antiprpton or anti-somthing to
+c               anihilate in the next step. We assume
+c               the anihilation takes place instantly
+c               after stopping. so don't add any time
+c               
+c                Move.Track.t= cTrack.t+1.e8  ! version <= 8.62
+                Move.Track.t = cTrack.t
           else
              call rndc(u)
              Move.Track.t = cTrack.t - log(u)*ctau
@@ -1361,8 +1375,7 @@ c               for heavey incident.
                call epfixTarget3(cTrack.p, Media(MediaNo), ia, iz)
             endif
             call ep2cosCond2(ia, iz)
-
-            call cinteNEP       ! cosmos 
+            call cinteNEP       ! cosmos eppp
             call eppushPtcl( cTrack )
          endif
       endif
@@ -1644,7 +1657,7 @@ c       low gamma
       gamma.w.x = -cs*sinr
       gamma.w.y = -sn*sinr
       gamma.w.z = cosr
-      call eptransVect(cTrack, gamma.w, gamma.w)
+      call eptransVect(cTrack.w, gamma.w, gamma.w)
       gamma.p.fm.p(4) = eg2
       call epe2p(gamma)
       call eppush(gamma)
